<?php
namespace App\Controller;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;

class Branch {

  private $branchService;

  public function __construct(\App\Service\Branch $branchService) {
      $this->branchService = $branchService;
  }

  public function getUnits(Request $request, Response $response) {
    try {
      $params = $request->getQueryParams();
      $search = isset($params['search']) ? strval(strtoupper($params['search'])) : 'T';
      $units = $this->branchService->getUnits($search);

      $response->getBody()->write(json_encode([
        'error'   => false,
        'message' => '',
        'data'    => $units,
        'pagination' => [
          'limit' => $params['limit'] ?? 50,
          'total' => count($units),
          'page' => $params['page'] ?? 1
      ]
    ]));
      return $response->withHeader('Content-Type', 'application/json');
    } catch (\Exception $e) {
      $response->getBody()->write(json_encode([
        'error'   => true,
        'message' => $e->getMessage(),
        'data'    => []
      ]));
      return $response;
    }
  }
  public function getAvailableStoresByUnit(Request $request, Response $response) {
    try {
      $params = $request->getParsedBody();
      $availableStoresByUnit = $this->branchService->getAvailableStoresByUnit($params);

      if(empty($availableStoresByUnit)) {
        throw new \Exception('Não há lojas disponíveis para bloqueio.');
      }

      $response->getBody()->write(json_encode([
        'error'   => false,
        'message' => '',
        'data'    => $availableStoresByUnit,
        'pagination' => [
          'limit' => $params['limit'] ?? 50,
          'total' => count($availableStoresByUnit),
          'page' => $params['page'] ?? 1
      ]
    ]));
      return $response->withHeader('Content-Type', 'application/json');
    } catch (\Exception $e) {
      $response->getBody()->write(json_encode([
        'error'   => true,
        'message' => $e->getMessage(),
        'data'    => []
      ]));
      return $response;
    }
  }

  public function blockStores(Request $request, Response $response) {
    try {
      $params = $request->getParsedBody();
      $this->branchService->blockStores($params);

      if (count($params['CDLOJA']) === 1) {
        $message = 'Loja bloqueada com sucesso.';
      } else {
        $message = 'Lojas bloqueadas com sucesso.';
      }

      $response->getBody()->write(json_encode([
        'error'   => false,
        'message' => $message,
        'data'    => [],
        'pagination' => [
          'limit' => $params['limit'] ?? 50,
          'total' => '',
          'page' => $params['page'] ?? 1
      ]
    ]));
      return $response->withHeader('Content-Type', 'application/json');
    } catch (\Exception $e) {
      $response->getBody()->write(json_encode([
        'error'   => true,
        'message' => 'Erro ao tentar bloquear loja(s). Detalhes: '.$e->getMessage(),
        'data'    => []
      ]));
      return $response;
    }
  }
}