<?php
namespace App\Factory;
use Doctrine\DBAL\Connection;
class Operator {
    private $connection;

    public function __construct(Connection $connection) {
        $this->connection = $connection;
    }

    public function getSMTP() {
      $sql = "
        SELECT DSSMTPAUTVND, DSEMAILAUVND, NRPORTAAUTVND, CDSENHAAUTVNDWEB,
          DSEMAILCLUSO, LOWER(DSSMTPCRIPT) AS DSSMTPCRIPT, IDTPAUTHSMTP
        FROM PARAMGERAL
      ";
  
      $stmt = $this->connection->prepare($sql);
      $result = $stmt->executeQuery();
      return $result->fetchAllAssociative();
    }

    public function updatePassword($encryptedNewPassword, $encryptedNewPasswordDelphi, $operatorId) {  
      $sql = "
        UPDATE OPERADOR
          SET CDSENHAOPERWEB = :CDSENHAOPERWEB,
              CDSENHOPER     = :CDSENHOPER,
              DTULTATU       = TO_DATE(TO_CHAR(SYSDATE, 'DD/MM/YYYY HH24:MI:SS'), 'DD/MM/YYYY HH24:MI:SS'),
              IDSTATUSENHA   = 'A'
        WHERE CDOPERADOR     = :CDOPERADOR
      ";
  
      $stmt = $this->connection->prepare($sql);
      $stmt->bindValue("CDSENHAOPERWEB", $encryptedNewPassword);
      $stmt->bindValue("CDSENHOPER", $encryptedNewPasswordDelphi);
      $stmt->bindValue("CDOPERADOR", $operatorId);
      $result = $stmt->executeQuery();
      return $result;
    }
    
    public function getPassword($operatorId) {
      $sql = "
        SELECT CDSENHAOPERWEB
          FROM OPERADOR
        WHERE  CDOPERADOR = :CDOPERADOR
      ";

      $stmt = $this->connection->prepare($sql);
      $stmt->bindValue("CDOPERADOR", $operatorId);
      $result = $stmt->executeQuery();
      return $result->fetchAllAssociative();
    }

	  public function validateEmail($email) {
		  $sql = "
          SELECT CDOPERADOR AS ID, NMOPERADOR AS NAME, DSEMAILOPER AS EMAIL
          FROM OPERADOR 
          WHERE DSEMAILOPER = :EMAIL
		    ";

		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("EMAIL", $email["form-email"]);
		$result = $stmt->executeQuery();
    return $result->fetchAllAssociative();
	  }

    public function resetPassword($password, $name) {
        $sql = "
            UPDATE OPERADOR
            SET CDSENHAOPERWEB = :CDSENHAOPERWEB
            WHERE UPPER(NMACESSO) = UPPER(:NMACESSO) 
        ";

        $stmt = $this->connection->prepare($sql);
        $stmt->bindValue("CDSENHAOPERWEB", $password);
        $stmt->bindValue("NMACESSO", $name);
        $result = $stmt->executeQuery();
        return $result->fetchAllAssociative();
    }

    public function login($operator, $password) {
        $sql = "
        SELECT CDOPERADOR AS ID, NMOPERADOR AS NAME, NRORG AS ORGANIZATION_ID, DSEMAILOPER AS EMAIL,
            IDIDIOMA AS IDIDIOMA, NMACESSO AS NMACESSO, NMCOMPLOPER AS NMCOMPLOPER, CDEMPRESA AS CDEMPRESA,
            NRPARCNEGOCIO AS NRPARCNEGOCIO, NRORG AS NRORG, NRORGTRAB AS NRORGTRAB, NRESTRUTTRAB AS NRESTRUTTRAB,
            CDFILIALSELECIONADA AS CDFILIALSELECIONADA, NRORGOPER AS NRORGOPER,
            CASE WHEN IDOPERATIVO = 'A' THEN 'Y' ELSE 'N' END AS IS_ACTIVE 
        FROM OPERADOR 
        WHERE (UPPER(NMACESSO) = UPPER(:OPERATOR) OR DSEMAILOPER = :OPERATOR) AND CDSENHAOPERWEB = :CDSENHAOPERWEB
        ";
        $stmt = $this->connection->prepare($sql);
        $stmt->bindValue("OPERATOR", $operator);
        $stmt->bindValue("CDSENHAOPERWEB", $password);
        $result = $stmt->executeQuery();
        return $result->fetchAllAssociative();
    }
}