import moment from 'moment';
import Format from './Format';
import { TimeOptions, TimeOptionsDifference } from './interfaces/TimeOptions';

type PreviousMonthParams = {
  months: number,
  includeCurrentMonth?: boolean,
};

class DateTime {
  public now(optionsToFormat: TimeOptions) {
    return Format.apply(new Date(), 'datetime', optionsToFormat);
  }

  public format(value: string | number, optionsToFormat: TimeOptions) {
    return Format.apply(value, 'datetime', optionsToFormat);
  }

  public difference(valueEnd: Date, valueInitial: Date, options: TimeOptionsDifference): number {
    return moment(valueEnd, options.typeFormatDefault)
      .diff(moment(valueInitial, options.typeFormatDefault), options.unit);
  }

  public getMonth(dateFormatted: string): string {
    return moment(dateFormatted, 'DD/MM/YYYY').format('MM');
  }

  public getDay(dateFormatted: string): number {
    return moment(dateFormatted, 'DD/MM/YYYY').date();
  }

  public getYear(dateFormatted: string): number {
    return moment(dateFormatted, 'DD/MM/YYYY').year();
  }

  public getAllMonthNames() {
    return ['Janeiro', 'Fevereiro', 'Março', 'Abril', 'Maio', 'Junho', 'Julho', 'Agosto', 'Setembro',
      'Outubro', 'Novembro', 'Dezembro'];
  }

  public getPreviousMonths({ months, includeCurrentMonth = false }: PreviousMonthParams) {
    const previousMonths = [];
    const monthNames = this.getAllMonthNames();
    const reversedMonthNames = [...monthNames].reverse();
    const monthsInYear = 12;
    const currentMonthIdx = new Date().getMonth();
    const currentMonth = monthNames[currentMonthIdx];
    let result = [];
    let monthIdx = monthsInYear - currentMonthIdx;

    const isLastMonthIdx = (idx: number) => idx === monthNames.length;
    while (previousMonths.length < months) {
      if (isLastMonthIdx(monthIdx)) monthIdx = 0;
      previousMonths.push(reversedMonthNames[monthIdx]);
      monthIdx += 1;
    }
    result = previousMonths.reverse();
    if (includeCurrentMonth) {
      result.push(currentMonth);
    }
    return result;
  }

  public getThirtyDaysAgo(): string {
    const currentDate = new Date();
    currentDate.setDate(currentDate.getDate() - 30);
    const formattedDate = `${String(currentDate.getDate()).padStart(2, '0')}/${
      String(currentDate.getMonth() + 1).padStart(2, '0')
    }/${currentDate.getFullYear()}`;

    return formattedDate;
  }
}
export default new DateTime();
